@@ -50,10 +50,11 @@ func TestLiveSigstoreVerifier(t *testing.T) {
 
 	for _, tc := range testcases {
 		t.Run(tc.name, func(t *testing.T) {
-			verifier := NewLiveSigstoreVerifier(SigstoreConfig{
+			verifier, err := NewLiveSigstoreVerifier(SigstoreConfig{
 				Logger:         io.NewTestHandler(),
 				TUFMetadataDir: o.Some(t.TempDir()),
 			})
+			require.NoError(t, err)
 
 			results, err := verifier.Verify(tc.attestations, publicGoodPolicy(t))
 
@@ -69,10 +70,11 @@ func TestLiveSigstoreVerifier(t *testing.T) {
 	}
 
 	t.Run("with 2/3 verified attestations", func(t *testing.T) {
-		verifier := NewLiveSigstoreVerifier(SigstoreConfig{
+		verifier, err := NewLiveSigstoreVerifier(SigstoreConfig{
 			Logger:         io.NewTestHandler(),
 			TUFMetadataDir: o.Some(t.TempDir()),
 		})
+		require.NoError(t, err)
 
 		invalidBundle := getAttestationsFor(t, "../test/data/sigstore-js-2.1.0-bundle-v0.1.json")
 		attestations := getAttestationsFor(t, "../test/data/sigstore-js-2.1.0_with_2_bundles.jsonl")
@@ -86,10 +88,11 @@ func TestLiveSigstoreVerifier(t *testing.T) {
 	})
 
 	t.Run("fail with 0/2 verified attestations", func(t *testing.T) {
-		verifier := NewLiveSigstoreVerifier(SigstoreConfig{
+		verifier, err := NewLiveSigstoreVerifier(SigstoreConfig{
 			Logger:         io.NewTestHandler(),
 			TUFMetadataDir: o.Some(t.TempDir()),
 		})
+		require.NoError(t, err)
 
 		invalidBundle := getAttestationsFor(t, "../test/data/sigstore-js-2.1.0-bundle-v0.1.json")
 		attestations := getAttestationsFor(t, "../test/data/sigstoreBundle-invalid-signature.json")
@@ -110,10 +113,11 @@ func TestLiveSigstoreVerifier(t *testing.T) {
 
 		attestations := getAttestationsFor(t, "../test/data/github_provenance_demo-0.0.12-py3-none-any-bundle.jsonl")
 
-		verifier := NewLiveSigstoreVerifier(SigstoreConfig{
+		verifier, err := NewLiveSigstoreVerifier(SigstoreConfig{
 			Logger:         io.NewTestHandler(),
 			TUFMetadataDir: o.Some(t.TempDir()),
 		})
+		require.NoError(t, err)
 
 		results, err := verifier.Verify(attestations, githubPolicy)
 		require.Len(t, results, 1)
@@ -123,11 +127,12 @@ func TestLiveSigstoreVerifier(t *testing.T) {
 	t.Run("with custom trusted root", func(t *testing.T) {
 		attestations := getAttestationsFor(t, "../test/data/sigstore-js-2.1.0_with_2_bundles.jsonl")
 
-		verifier := NewLiveSigstoreVerifier(SigstoreConfig{
+		verifier, err := NewLiveSigstoreVerifier(SigstoreConfig{
 			Logger:         io.NewTestHandler(),
 			TrustedRoot:    test.NormalizeRelativePath("../test/data/trusted_root.json"),
 			TUFMetadataDir: o.Some(t.TempDir()),
 		})
+		require.NoError(t, err)
 
 		results, err := verifier.Verify(attestations, publicGoodPolicy(t))
 		require.Len(t, results, 2)
